==> Tekkotsu_2.1.tar.gz: Tekkotsu_2.1/Shared/ProjectInterface.cc <==
#include "ProjectInterface.h"
#include "Events/VisionObjectEvent.h"

FilterBankGenerator * ProjectInterface::defRawCameraGenerator=0;
FilterBankGenerator * ProjectInterface::defInterleavedYUVGenerator=0;
FilterBankGenerator * ProjectInterface::defColorJPEGGenerator=0;
FilterBankGenerator * ProjectInterface::defGrayscaleJPEGGenerator=0;
FilterBankGenerator * ProjectInterface::defSegmentedColorGenerator=0;
FilterBankGenerator * ProjectInterface::defRLEGenerator=0;
FilterBankGenerator * ProjectInterface::defRegionGenerator=0;

unsigned int ProjectInterface::visRawCameraSID=0;

unsigned int ProjectInterface::visInterleaveSID=0;

unsigned int ProjectInterface::visColorJPEGSID=0;
unsigned int ProjectInterface::visGrayscaleJPEGSID=1;

unsigned int ProjectInterface::visSegmentSID=0;

unsigned int ProjectInterface::visRLESID=0;

unsigned int ProjectInterface::visRegionSID=0;

unsigned int ProjectInterface::visPinkBallSID=0;
unsigned int ProjectInterface::visBlueBallSID=1;
unsigned int ProjectInterface::visHandSID=2;

unsigned int ProjectInterface::doubleLayer=5;
unsigned int ProjectInterface::fullLayer=4;
unsigned int ProjectInterface::halfLayer=3;
unsigned int ProjectInterface::quarterLayer=2;
unsigned int ProjectInterface::eighthLayer=1;
unsigned int ProjectInterface::sixteenthLayer=0;

/*! @file
 * @brief Provides instantiation of the non-required members of ProjectInterface
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_1 $
 * $Revision: 1.4 $
 * $State: Exp $
 * $Date: 2003/12/11 05:49:30 $
 */

==> Tekkotsu_2.2.tar.gz: Tekkotsu_2.2/Shared/ProjectInterface.cc <==
#include "ProjectInterface.h"
#include "Events/VisionObjectEvent.h"

FilterBankGenerator * ProjectInterface::defRawCameraGenerator=0;
FilterBankGenerator * ProjectInterface::defInterleavedYUVGenerator=0;
FilterBankGenerator * ProjectInterface::defColorJPEGGenerator=0;
FilterBankGenerator * ProjectInterface::defGrayscaleJPEGGenerator=0;
SegmentedColorGenerator * ProjectInterface::defSegmentedColorGenerator=0;
FilterBankGenerator * ProjectInterface::defRLEGenerator=0;
FilterBankGenerator * ProjectInterface::defRegionGenerator=0;

unsigned int ProjectInterface::visRawCameraSID=0;

unsigned int ProjectInterface::visInterleaveSID=0;

unsigned int ProjectInterface::visColorJPEGSID=0;
unsigned int ProjectInterface::visGrayscaleJPEGSID=1;

unsigned int ProjectInterface::visSegmentSID=0;

unsigned int ProjectInterface::visRLESID=0;

unsigned int ProjectInterface::visRegionSID=0;

unsigned int ProjectInterface::visPinkBallSID=0;
unsigned int ProjectInterface::visBlueBallSID=1;
unsigned int ProjectInterface::visHandSID=2;

unsigned int ProjectInterface::doubleLayer=5;
unsigned int ProjectInterface::fullLayer=4;
unsigned int ProjectInterface::halfLayer=3;
unsigned int ProjectInterface::quarterLayer=2;
unsigned int ProjectInterface::eighthLayer=1;
unsigned int ProjectInterface::sixteenthLayer=0;

/*! @file
 * @brief Provides instantiation of the non-required members of ProjectInterface
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_2 $
 * $Revision: 1.5 $
 * $State: Exp $
 * $Date: 2004/07/16 19:25:09 $
 */
